# Django-Geocode

**Django app that helps manage geo-coding of model objects.**

[![build-status-image]][travis]

# Overview

Django-Geocode is a django app that helps manage geo-coding of model objects..

# Requirements

* Python (2.7, 3.4)
* Django (1.6, 1.8)

# Installation

Install using `pip`...

    pip install django-geocode

Add `'geocode'` to your `INSTALLED_APPS` setting.

    INSTALLED_APPS = (
        ...
        'geocode',
    )

More docs to come...

That's it, we're done!

[build-status-image]: https://secure.travis-ci.org/simonluijk/django-geocode.png?branch=master
[travis]: http://travis-ci.org/simonluijk/django-geocode?branch=master
